@@ -1,13 +1,13 @@
 # -*- coding:utf-8 -*-
 
 """myelectricaldatapy package."""
-from .myelectricaldata import EnedisGateway, EnedisByPDL
-from .exceptions import EnedisException, LimitReached, GatewayException
+from .exceptions import EnedisException, GatewayException, LimitReached
+from .myelectricaldata import EnedisByPDL, EnedisGateway
 
 __all__ = [
     "EnedisGateway",
     "EnedisByPDL",
     "EnedisException",
     "LimitReached",
-    "GatewayException"
+    "GatewayException",
 ]
